@@ -1,14 +1,11 @@
 import base64
 import io
-import logging
 import os
 import sys
 from typing import Iterable, Iterator, List, Optional, Sequence, TextIO
 
 import click
 
-logger = logging.getLogger(__name__)
-
 
 class ProgramTerminatedError(Exception):
     """Terminate program with an error"""
